@@ -23,7 +23,8 @@ test_that("get_sysdata returns all expected entries", {
   expect_notnull(sysdata$urldata)
   expect_notnull(sysdata$urlsysdata)
   expect_notnull(sysdata$bibentries)
-  expect_equal(length(names(sysdata)), 9)
+  expect_notnull(sysdata$creation)
+  expect_gt(length(names(sysdata)), 9)
 })
 
 test_that("sysdata gets downloaded", {
